@@ -20,9 +20,20 @@ from blosc.toplevel import (
     free_resources,
     set_nthreads,
     compressor_list,
+    code_to_name,
+    name_to_code,
+    clib_info,
+    get_clib,
     print_versions,
     )
 
+# Dictionaries for the maps between compressor names and libs
+cnames = compressor_list()
+# Map for compression names and libs
+cname2clib = dict((name, clib_info(name)[0]) for name in cnames)
+# Map for compression libraries and versions
+clib_versions = dict(clib_info(name) for name in cnames)
+
 # Blosc symbols that we want to export
 from blosc.blosc_extension import (
     BLOSC_VERSION_STRING,
@@ -49,4 +60,5 @@ from blosc.test import run as test
 __all__ = ['compress', 'compress_ptr', 'decompress', 'decompress_ptr',
            'pack_array', 'unpack_array',
            'detect_number_of_cores', 'free_resources', 'set_nthreads',
-           'compressor_list', 'print_versions', 'test']
+           'compressor_list', 'clib_info', 'get_clib',
+           'print_versions', 'test']
