@@ -23,6 +23,13 @@ class TestCodec(unittest.TestCase):
         d = blosc.decompress(c)
         self.assertEqual(s, d)
 
+    def test_get_clib(self):
+        s = b'0123456789'
+        for cname in blosc.compressor_list():
+            c = blosc.compress(s, typesize=1, cname=cname)
+            clib = blosc.get_clib(c)
+            self.assert_(clib == blosc.cname2clib[cname])
+
     def test_all_compressors(self):
         s = b'0123456789'*100
         for cname in blosc.compressor_list():
